==> aroundme_0_6_4.zip: aroundme_0_6_4/aroundme/chl_edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "inc/header.inc.php";


//ACS check
if (!empty($_REQUEST['group_id'])) {
	$group_id = $_REQUEST['group_id'];
	include_once ('inc/header_group.inc.php');
	
	if (!$group_acs->checkPermission($c_acs['arr_acs']['resource']['group']['channels'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
		header("Location: grp_view.php?group_id=" . $_REQUEST['group_id'] . "&" . strip_tags(SID));
		exit;
	}
	
	require_once($languagePath . 'grp_common.lang.php');
}
elseif (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['node']['channels'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['user_homepage'] . "?" . strip_tags(SID));
	exit;
}


// SETUP CHANNEL --------------------------------------------------------
require_once('class/Channel.class.php');
$channel = new Channel($db);


//SETUP RSP ---------------------------------------------------------
require_once('class/Rsp.class.php');
$rsp = new Rsp($db, $c_node['rsp']['item_type']['channel']);
$rsp->user_id = $me['user_id'];

if($c_node['rsp']['node']['auto_publish'] == 1) {
	$rsp->status_id = $c_node['rsp']['status']['live'];
}
else {
	$rsp->status_id = $c_node['rsp']['status']['pending'];
}

if (isset($group_id)) {
    $rsp->group_id = $group_id;
}

if (isset($frmdata['channel_insert'])) {
	$channel->user_id = $me['user_id'];
	$channel->insertChannel($frmdata);
	
	if (empty($GLOBALS['am_error_log'])) {
		$temp['item_id'] = $channel->channel_id;
		$temp['language_id'] = $me['language_id'];
		
		//delete all
		$rsp->deleteRspItem($channel->channel_id);

		//insert node rsp entry
		if (!empty($frmdata['rsp_node'])) {
			$temp['level_id'] = $c_node['rsp']['rsp_level']['node'];
			$rsp->insertRspItem($temp);
		}
		
		if (!empty($frmdata['group_id'])) { // page under group section
			header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&channel_id=" . $channel->channel_id . "&" . strip_tags(SID));
			exit;
		}
		else {
			header("Location: chl_view.php?channel_id=" . $channel->channel_id . "&" . strip_tags(SID));
			exit;
		}
	}
}
elseif (isset($frmdata['channel_save'])) {
	$channel->updateChannel($frmdata);
	
	if (empty($GLOBALS['am_error_log'])) {
		$temp['language_id'] = $me['language_id'];
		$temp['item_id'] = $frmdata['channel_id'];
		//delete all
		$rsp->deleteRspItem($frmdata['channel_id']);

		//insert node rsp entry
		if (!empty($frmdata['rsp_node'])) {
			$temp['level_id'] = $c_node['rsp']['rsp_level']['node'];
			$rsp->insertRspItem($temp);
		}
		
		if (!empty($frmdata['group_id'])) { // page under group section
			header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&channel_id=" . $frmdata['channel_id'] . "&" . strip_tags(SID));
			exit;
		}
		else {
			header("Location: chl_view.php?channel_id=" . $frmdata['channel_id'] . "&" . strip_tags(SID));
			exit;
		}
	}
}
elseif (isset($frmdata['channel_delete'])) {
	$channel->deleteChannel($frmdata['channel_id']);
	
	if (!empty($frmdata['group_id'])) { // page under group section
		header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&" . strip_tags(SID));
		exit;
	}
	else {
		header("Location: chl_view.php" . strip_tags(SID));
		exit;
	}
}


//if we get a channel ID get the channel list
if (isset($_REQUEST['channel_id'])) {
	$output_channel = $channel->selChannel($_REQUEST['channel_id']);
}


//RSP items
if (isset($output_channel['channel_id'])) {
	$output_channel['rsp'] = $rsp->selRspItem($output_channel['channel_id']);
}

//move vars to template
if (!empty($output_channel)) {
	$body->set('channel', $output_channel);
}

if (!empty($output_group)) {
	$body->set('group', $output_group);
}

$body->set('rspconfig', $c_node['rsp']);

$template_pageLink = $lang['txt_channels'];

include "inc/footer.inc.php";

?>

==> aroundme_0_6_5.zip: aroundme_0_6_5/aroundme/chl_edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "inc/header.inc.php";


//ACS check
if (!empty($_REQUEST['group_id'])) {
	$group_id = $_REQUEST['group_id'];
	include_once ('inc/header_group.inc.php');
	
	if (!$group_acs->checkPermission($c_acs['arr_acs']['resource']['group']['channels'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
		header("Location: grp_view.php?group_id=" . $_REQUEST['group_id'] . "&" . strip_tags(SID));
		exit;
	}
	
	require_once($languagePath . 'grp_common.lang.php');
}
elseif (!$user_acs->checkPermission($c_acs['arr_acs']['resource']['node']['channels'], $c_acs['arr_acs']['privilege']['allow_access'])) { //resourece_id, Priv_id
	header("Location: " . $_SESSION['user_homepage'] . "?" . strip_tags(SID));
	exit;
}


// SETUP LANGUAGE --------------------------------------------------------
require_once($languagePath . 'common.lang.php');
require_once($languagePath . 'chl_view.lang.php');


// SETUP CHANNEL --------------------------------------------------------
require_once('class/Channel.class.php');
$channel = new Channel($db);


//SETUP RSP ---------------------------------------------------------
require_once('class/Rsp.class.php');
$rsp = new Rsp($db, $c_node['rsp']['item_type']['channel']);
$rsp->user_id = $me['user_id'];

if($c_node['rsp']['node']['auto_publish'] == 1) {
	$rsp->status_id = $c_node['rsp']['status']['live'];
}
else {
	$rsp->status_id = $c_node['rsp']['status']['pending'];
}

if (isset($group_id)) {
    $rsp->group_id = $group_id;
}

if (isset($frmdata['channel_insert'])) {
	$channel->user_id = $me['user_id'];
	$channel->insertChannel($frmdata);
	
	if (empty($GLOBALS['am_error_log'])) {
		$temp['item_id'] = $channel->channel_id;
		$temp['language_id'] = $me['language_id'];
		
		//delete all
		$rsp->deleteRspItem($channel->channel_id);

		//insert node rsp entry
		if (!empty($frmdata['rsp_node'])) {
			$temp['level_id'] = $c_node['rsp']['rsp_level']['node'];
			$rsp->insertRspItem($temp);
		}
		
		if (!empty($frmdata['group_id'])) { // page under group section
			header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&channel_id=" . $channel->channel_id . "&" . strip_tags(SID));
			exit;
		}
		else {
			header("Location: chl_view.php?channel_id=" . $channel->channel_id . "&" . strip_tags(SID));
			exit;
		}
	}
}
elseif (isset($frmdata['channel_save'])) {
	$channel->updateChannel($frmdata);
	
	if (empty($GLOBALS['am_error_log'])) {
		$temp['language_id'] = $me['language_id'];
		$temp['item_id'] = $frmdata['channel_id'];
		//delete all
		$rsp->deleteRspItem($frmdata['channel_id']);

		//insert node rsp entry
		if (!empty($frmdata['rsp_node'])) {
			$temp['level_id'] = $c_node['rsp']['rsp_level']['node'];
			$rsp->insertRspItem($temp);
		}
		
		if (!empty($frmdata['group_id'])) { // page under group section
			header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&channel_id=" . $frmdata['channel_id'] . "&" . strip_tags(SID));
			exit;
		}
		else {
			header("Location: chl_view.php?channel_id=" . $frmdata['channel_id'] . "&" . strip_tags(SID));
			exit;
		}
	}
}
elseif (isset($frmdata['channel_delete'])) {
	$channel->deleteChannel($frmdata['channel_id']);
	
	if (!empty($frmdata['group_id'])) { // page under group section
		header("Location: chl_view.php?group_id=" . $frmdata['group_id'] . "&" . strip_tags(SID));
		exit;
	}
	else {
		header("Location: chl_view.php" . strip_tags(SID));
		exit;
	}
}


//if we get a channel ID get the channel list
if (isset($_REQUEST['channel_id'])) {
	$output_channel = $channel->selChannel($_REQUEST['channel_id']);
}


//RSP items
if (isset($output_channel['channel_id'])) {
	$output_channel['rsp'] = $rsp->selRspItem($output_channel['channel_id']);
}

//move vars to template
if (!empty($output_channel)) {
	$body->set('channel', $output_channel);
}

if (!empty($output_group)) {
	$body->set('group', $output_group);
}

$body->set('rspconfig', $c_node['rsp']);

include "inc/footer.inc.php";

?>
